import type { MaintStandVO } from './model';

import type { ID, IDS, PageResult } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  maintStandExport = '/eims/maintStand/export',
  maintStandList = '/eims/maintStand/list',
  root = '/eims/maintStand'
}

/**
 * 查询保养标准列表
 * @param query
 * @returns {*}
 */

export function listMaintStand(params?: any) {
  return requestClient.get<PageResult<MaintStandVO>>(Api.maintStandList, { params });
}

/**
 * 查询保养标准详细
 * @param maintStandId
 */
export function getMaintStand(maintStandId: ID) {
  return requestClient.get<MaintStandVO>(`${Api.root}/${maintStandId}`);
}

/**
 * 新增保养标准
 * @param data
 */
export function addMaintStand(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改保养标准
 * @param data
 */
export function updateMaintStand(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除保养标准
 * @param maintStandId
 */
export function delMaintStand(maintStandId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${maintStandId}`);
}
/**
 * 导出
 * @param
 */
export function maintStandExport(data: any) {
  return commonExport(Api.maintStandExport, data);
}
